@@ -1,6 +1,6 @@
 def read(filname, delimiter=','):
     res = []
-    with open(filname, 'r') as f:
+    with open(filname, 'r', encoding = 'utf-8') as f:
         table = f.readlines()
     for row in table:
         res.append(row.strip('\n').split(delimiter))
